@@ -1,14 +1,20 @@
-"""
-# Copyright Xiang Wang, Inc. All Rights Reserved
+# Copyright (c) 2020 DataArk Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# http://www.apache.org/licenses/LICENSE-2.0
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# Author: Xiang Wang, xiangking1995@163.com
+# Status: Active
 
-Author: Xiang Wang, xiangking1995@163.com
-Status: Active
-"""
 
 import torch
 
@@ -60,6 +66,8 @@ class GlobalPointerNERDataset(TokenClassificationDataset):
                         continue
                     global_label[self.cat2id[info_['type']], start_idx+1, end_idx+1] = 1
 
+            global_label = torch.tensor(global_label).to_sparse()
+
             features.append({
                 'input_ids': input_ids,
                 'attention_mask': input_mask,
