@@ -5,7 +5,10 @@ from ark_nlp.processor.tokenizer.transfomer import SpanTokenizer as Tokenizer
 from ark_nlp.processor.tokenizer.transfomer import SpanTokenizer as CasRelRETokenizer
 
 from ark_nlp.nn import BertConfig as CasRelBertConfig
+from ark_nlp.nn import BertConfig as ModuleConfig
+
 from ark_nlp.model.re.casrel_bert.casrel_bert import CasRelBert
+from ark_nlp.model.re.casrel_bert.casrel_bert import CasRelBert as Module
 
 from ark_nlp.factory.optimizer import get_default_bert_optimizer as get_default_model_optimizer
 from ark_nlp.factory.optimizer import get_default_bert_optimizer as get_default_casrel_bert_optimizer
