@@ -5,7 +5,10 @@ from ark_nlp.processor.tokenizer.transfomer import SpanTokenizer as Tokenizer
 from ark_nlp.processor.tokenizer.transfomer import SpanTokenizer as PRGCRETokenizer
 
 from ark_nlp.nn import BertConfig as PRGCBertConfig
+from ark_nlp.nn import BertConfig as ModuleConfig
+
 from ark_nlp.model.re.prgc_bert.prgc_bert import PRGCBert
+from ark_nlp.model.re.prgc_bert.prgc_bert import PRGCBert as Module
 
 from ark_nlp.factory.optimizer import get_default_bert_optimizer as get_default_model_optimizer
 from ark_nlp.factory.optimizer import get_default_bert_optimizer as get_default_prgc_bert_optimizer
